@@ -16,7 +16,7 @@ Output is in the form of zero or more JSON documents, indicating the device, top
 latest sense event.
 
 SYNOPSIS
-aws_byline.py { -d DEVICE | -t TOPIC [-l] | -a } [-x EXCLUDED] [-v]
+aws_byline.py { -d DEVICE | -t TOPIC [-l] | -a } [-x EXCLUDED] [-m] [-v]
 
 EXAMPLES
 aws_byline.py -t south-coast-science-demo -v -x /control
@@ -109,7 +109,7 @@ if __name__ == '__main__':
             group = manager.find_bylines_for_device(cmd.device, excluded=cmd.excluded)
 
         else:
-            group = manager.find_bylines_for_topic('', excluded=cmd.excluded)
+            group = manager.find_bylines(excluded=cmd.excluded)     # all
 
         # report...
         for byline in group.bylines:
@@ -118,11 +118,13 @@ if __name__ == '__main__':
                     latest = byline
 
             else:
-                print(JSONify.dumps(byline))
+                jdict = byline.as_json(include_message=cmd.include_messages)
+                print(JSONify.dumps(jdict))
                 sys.stdout.flush()
 
         if cmd.latest and latest is not None:
-            print(JSONify.dumps(latest))
+            jdict = latest.as_json(include_message=cmd.include_messages)
+            print(JSONify.dumps(jdict))
 
 
     # ----------------------------------------------------------------------------------------------------------------
@@ -135,8 +137,7 @@ if __name__ == '__main__':
         print("aws_byline: %s" % repr(ex), file=sys.stderr)
 
     except KeyboardInterrupt:
-        if cmd.verbose:
-            print("aws_byline: KeyboardInterrupt", file=sys.stderr)
+        print(file=sys.stderr)
 
     finally:
         if cmd.verbose and group is not None and len(group):
